@@ -37,7 +37,7 @@ const Page: React.FC = () => {
   const [rawData, setRawData] = useState<Record<string, any>>({});
   const [id, setId] = useState('');
   const [editorMode, setEditorMode] = useState<'create' | 'update'>('create');
-  const { paginationConfig, savePageList } = usePagination();
+  const { paginationConfig, savePageList, checkPageList } = usePagination();
 
   const columns: ProColumns<ConsumerModule.ResEntity>[] = [
     {
@@ -59,7 +59,7 @@ const Page: React.FC = () => {
       title: formatMessage({ id: 'menu.plugin' }),
       dataIndex: 'plugins',
       hideInSearch: true,
-      render: (_, record) => Object.keys(record.plugins).join(','),
+      render: (_, record) => Object.keys(record.plugins || []).join(','),
     },
     {
       title: formatMessage({ id: 'component.global.operation' }),
@@ -95,8 +95,7 @@ const Page: React.FC = () => {
                 notification.success({
                   message: `${formatMessage({ id: 'component.global.delete.consumer.success' })}`,
                 });
-                /* eslint-disable no-unused-expressions */
-                ref.current?.reload();
+                checkPageList(ref);
               });
             }}
           >
