@@ -88,6 +88,63 @@ var _ = ginkgo.Describe("Upstream", func() {
 			ExpectStatus: http.StatusOK,
 		})
 	})
+	ginkgo.It("create upstream3 success when pass host is 'node' and nodes without port", func() {
+		ginkgo.By("create upstream3", func() {
+			createUpstreamBody := make(map[string]interface{})
+			createUpstreamBody["name"] = "upstream3"
+			createUpstreamBody["nodes"] = map[string]float64{base.UpstreamIp: 100}
+			createUpstreamBody["type"] = "roundrobin"
+			createUpstreamBody["pass_host"] = "node"
+
+			_createUpstreamBody, err := json.Marshal(createUpstreamBody)
+			gomega.Expect(err).To(gomega.BeNil())
+			base.RunTestCase(base.HttpTestCase{
+				Object:       base.ManagerApiExpect(),
+				Method:       http.MethodPut,
+				Path:         "/apisix/admin/upstreams/3",
+				Body:         string(_createUpstreamBody),
+				Headers:      map[string]string{"Authorization": base.GetToken()},
+				ExpectStatus: http.StatusOK,
+			})
+		})
+
+		ginkgo.By("create route using the upstream3", func() {
+			base.RunTestCase(base.HttpTestCase{
+				Object: base.ManagerApiExpect(),
+				Method: http.MethodPut,
+				Path:   "/apisix/admin/routes/1",
+				Body: `{
+				 "name": "route1",
+				 "uri": "/hello",
+				 "upstream_id": "3"
+			 }`,
+				Headers:      map[string]string{"Authorization": base.GetToken()},
+				ExpectStatus: http.StatusOK,
+				Sleep:        base.SleepTime,
+			})
+		})
+
+		ginkgo.By("hit the route just created", func() {
+			base.RunTestCase(base.HttpTestCase{
+				Object:       base.APISIXExpect(),
+				Method:       http.MethodGet,
+				Path:         "/hello",
+				ExpectStatus: http.StatusOK,
+				ExpectBody:   "hello",
+				Sleep:        base.SleepTime,
+			})
+		})
+
+		ginkgo.By("delete route", func() {
+			base.RunTestCase(base.HttpTestCase{
+				Object:       base.ManagerApiExpect(),
+				Method:       http.MethodDelete,
+				Path:         "/apisix/admin/routes/1",
+				Headers:      map[string]string{"Authorization": base.GetToken()},
+				ExpectStatus: http.StatusOK,
+			})
+		})
+	})
 	ginkgo.It("create upstream failed, name existed", func() {
 		createUpstreamBody := make(map[string]interface{})
 		createUpstreamBody["name"] = "upstream2"
@@ -252,6 +309,15 @@ var _ = ginkgo.Describe("Upstream", func() {
 			ExpectStatus: http.StatusOK,
 		})
 	})
+	ginkgo.It("delete upstream3", func() {
+		base.RunTestCase(base.HttpTestCase{
+			Object:       base.ManagerApiExpect(),
+			Method:       http.MethodDelete,
+			Path:         "/apisix/admin/upstreams/3",
+			Headers:      map[string]string{"Authorization": base.GetToken()},
+			ExpectStatus: http.StatusOK,
+		})
+	})
 	ginkgo.It("hit the route just deleted", func() {
 		base.RunTestCase(base.HttpTestCase{
 			Object:       base.APISIXExpect(),
